@@ -1,9 +1,11 @@
 use once_cell::sync::Lazy;
+use preset_env_base::{
+    version::{should_enable, Version},
+    BrowserData, Versions,
+};
 use string_enum::StringEnum;
 use swc_common::collections::AHashMap;
 
-use crate::{version::should_enable, BrowserData, Version, Versions};
-
 impl Feature {
     pub fn should_enable(self, target: Versions, bugfixes: bool, default: bool) -> bool {
         let f = if bugfixes {
